@@ -13,6 +13,7 @@ Features:
 - Easy integration with existing agents and workflows
 """
 
+import os
 import time
 import json
 import threading
@@ -32,6 +33,7 @@ except ImportError:
 logger = logging.getLogger(__name__)
 
 
+
 class PerformanceMonitor:
     """
     User-friendly performance monitoring for functions, API calls, and workflows.
@@ -50,6 +52,20 @@ class PerformanceMonitor:
         Args:
             max_entries: Maximum number of performance entries to keep in memory
         """
+        # Check if performance monitoring is disabled
+        from .telemetry import _is_monitoring_disabled
+        self._monitoring_disabled = _is_monitoring_disabled()
+        
+        # If monitoring is disabled, use minimal initialization
+        if self._monitoring_disabled:
+            self.max_entries = 0
+            self._lock = None
+            self._function_stats = {}
+            self._api_calls = {}
+            self._function_flow = []
+            self._active_calls = {}
+            self._telemetry = None
+            return
         self.max_entries = max_entries
         self._lock = threading.RLock()
         
@@ -97,6 +113,12 @@ class PerformanceMonitor:
             def my_function():
                 return "result"
         """
+        # If monitoring is disabled, return unmodified function
+        if self._monitoring_disabled:
+            def decorator(func: Callable) -> Callable:
+                return func
+            return decorator
+        
         def decorator(func: Callable) -> Callable:
             name = func_name or f"{func.__module__}.{func.__qualname__}"
             
@@ -170,6 +192,10 @@ class PerformanceMonitor:
             with performance_monitor.track_api_call("openai", "/v1/chat/completions"):
                 response = openai_client.chat.completions.create(...)
         """
+        # If monitoring is disabled, provide no-op context manager
+        if self._monitoring_disabled:
+            yield
+            return
         call_name = f"{api_name}:{endpoint}" if endpoint else api_name
         start_time = time.time()
         
@@ -189,6 +215,9 @@ class PerformanceMonitor:
     def _record_function_performance(self, func_name: str, execution_time: float, 
                                    success: bool, error: Optional[str] = None):
         """Record function performance statistics."""
+        if self._monitoring_disabled:
+            return
+            
         with self._lock:
             stats = self._function_stats[func_name]
             stats['call_count'] += 1
@@ -212,6 +241,9 @@ class PerformanceMonitor:
     def _record_api_call(self, api_name: str, execution_time: float,
                         success: bool, error: Optional[str] = None):
         """Record API call performance statistics."""
+        if self._monitoring_disabled:
+            return
+            
         with self._lock:
             stats = self._api_calls[api_name]
             stats['call_count'] += 1
@@ -241,6 +273,10 @@ class PerformanceMonitor:
         Returns:
             Dictionary with performance statistics
         """
+        # If monitoring is disabled, return empty results
+        if self._monitoring_disabled:
+            return {}
+            
         with self._lock:
             if func_name:
                 if func_name not in self._function_stats:
@@ -287,6 +323,10 @@ class PerformanceMonitor:
         Returns:
             Dictionary with API call performance statistics
         """
+        # If monitoring is disabled, return empty results
+        if self._monitoring_disabled:
+            return {}
+            
         with self._lock:
             if api_name:
                 if api_name not in self._api_calls:
@@ -515,6 +555,9 @@ class PerformanceMonitor:
         Returns:
             Performance data in requested format
         """
+        if self._monitoring_disabled:
+            return {} if format == "dict" else "{}"
+            
         data = {
             'functions': self.get_function_performance(),
             'api_calls': self.get_api_call_performance(),
@@ -526,6 +569,119 @@ class PerformanceMonitor:
         if format == "json":
             return json.dumps(data, indent=2)
         return data
+    
+    def export_metrics_for_external_apm(self, service_name: str = "praisonai-agents") -> Dict[str, Any]:
+        """
+        Export lightweight metrics suitable for external APM tools like DataDog or New Relic.
+        
+        This method provides a minimal overhead way to export key performance metrics
+        without the expensive flow analysis operations.
+        
+        Args:
+            service_name: Name of the service for APM tagging
+            
+        Returns:
+            Dictionary with lightweight metrics suitable for external monitoring
+        """
+        if self._monitoring_disabled:
+            return {}
+            
+        timestamp = datetime.now().isoformat()
+        metrics = []
+        
+        # Function performance metrics (lightweight)
+        for func_name, stats in self._function_stats.items():
+            if stats['call_count'] > 0:
+                avg_duration = stats['total_time'] / stats['call_count']
+                error_rate = stats['error_count'] / stats['call_count']
+                
+                # Create metrics in a format suitable for external APM
+                metrics.append({
+                    'metric_name': 'function.execution.duration',
+                    'metric_type': 'gauge',
+                    'value': avg_duration,
+                    'timestamp': timestamp,
+                    'tags': {
+                        'service': service_name,
+                        'function_name': func_name,
+                        'unit': 'seconds'
+                    }
+                })
+                
+                metrics.append({
+                    'metric_name': 'function.execution.count', 
+                    'metric_type': 'counter',
+                    'value': stats['call_count'],
+                    'timestamp': timestamp,
+                    'tags': {
+                        'service': service_name,
+                        'function_name': func_name
+                    }
+                })
+                
+                metrics.append({
+                    'metric_name': 'function.error.rate',
+                    'metric_type': 'gauge', 
+                    'value': error_rate,
+                    'timestamp': timestamp,
+                    'tags': {
+                        'service': service_name,
+                        'function_name': func_name,
+                        'unit': 'ratio'
+                    }
+                })
+        
+        # API call metrics (lightweight)
+        for api_name, stats in self._api_calls.items():
+            if stats['call_count'] > 0:
+                avg_duration = stats['total_time'] / stats['call_count'] 
+                success_rate = stats['success_count'] / stats['call_count']
+                
+                metrics.append({
+                    'metric_name': 'api.call.duration',
+                    'metric_type': 'gauge',
+                    'value': avg_duration,
+                    'timestamp': timestamp,
+                    'tags': {
+                        'service': service_name,
+                        'api_name': api_name,
+                        'unit': 'seconds'
+                    }
+                })
+                
+                metrics.append({
+                    'metric_name': 'api.call.count',
+                    'metric_type': 'counter',
+                    'value': stats['call_count'], 
+                    'timestamp': timestamp,
+                    'tags': {
+                        'service': service_name,
+                        'api_name': api_name
+                    }
+                })
+                
+                metrics.append({
+                    'metric_name': 'api.success.rate',
+                    'metric_type': 'gauge',
+                    'value': success_rate,
+                    'timestamp': timestamp, 
+                    'tags': {
+                        'service': service_name,
+                        'api_name': api_name,
+                        'unit': 'ratio'
+                    }
+                })
+        
+        return {
+            'service_name': service_name,
+            'timestamp': timestamp,
+            'metrics': metrics,
+            'metadata': {
+                'total_functions_monitored': len(self._function_stats),
+                'total_apis_monitored': len(self._api_calls),
+                'monitoring_enabled': not self._monitoring_disabled
+            }
+        }
 
 
 # Global performance monitor instance
@@ -570,4 +726,9 @@ def get_slowest_apis(limit: int = 10) -> List[Dict[str, Any]]:
 
 def clear_performance_data():
     """Clear all performance monitoring data."""
-    performance_monitor.clear_statistics()
\ No newline at end of file
+    performance_monitor.clear_statistics()
+
+
+def export_external_apm_metrics(service_name: str = "praisonai-agents") -> Dict[str, Any]:
+    """Export lightweight metrics for external APM tools."""
+    return performance_monitor.export_metrics_for_external_apm(service_name)
\ No newline at end of file
